==> networking_arista-2016.1.4.tar.gz: networking_arista-2016.1.4/networking_arista/common/exceptions.py <==
# Copyright (c) 2013 OpenStack Foundation
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
# implied.
# See the License for the specific language governing permissions and
# limitations under the License.


"""Exceptions used by Arista ML2 Mechanism Driver."""

from neutron.common import exceptions


class AristaRpcError(exceptions.NeutronException):
    message = _('%(msg)s')


class AristaConfigError(exceptions.NeutronException):
    message = _('%(msg)s')


class AristaServicePluginRpcError(exceptions.NeutronException):
    message = _('%(msg)s')


class AristaServicePluginConfigError(exceptions.NeutronException):
    message = _('%(msg)s')


class VlanUnavailable(exceptions.NeutronException):
    """An exception indicating VLAN creation failed because it's not available.

    A specialization of the NeutronException indicating network creation failed
    because a specified VLAN is unavailable on the physical network.

    :param vlan_id: The VLAN ID.
    :param physical_network: The physical network.
    """
    message = _("Unable to create the network. "
                "The VLAN %(vlan_id)s on physical network "
                "%(physical_network)s is not available.")

==> networking_arista-2017.2.11.tar.gz: networking_arista-2017.2.11/networking_arista/common/exceptions.py <==
# Copyright (c) 2013 OpenStack Foundation
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
# implied.
# See the License for the specific language governing permissions and
# limitations under the License.


"""Exceptions used by Arista ML2 Mechanism Driver."""

from neutron_lib import exceptions

from networking_arista._i18n import _


class AristaRpcError(exceptions.NeutronException):
    message = _('%(msg)s')


class AristaConfigError(exceptions.NeutronException):
    message = _('%(msg)s')


class AristaServicePluginRpcError(exceptions.NeutronException):
    message = _('%(msg)s')


class AristaServicePluginConfigError(exceptions.NeutronException):
    message = _('%(msg)s')


class AristaSecurityGroupError(exceptions.NeutronException):
    message = _('%(msg)s')


class AristaServicePluginInvalidCommand(exceptions.NeutronException):
    message = _('%(msg)s')


class VlanUnavailable(exceptions.NeutronException):
    """An exception indicating VLAN creation failed because it's not available.

    A specialization of the NeutronException indicating network creation failed
    because a specified VLAN is unavailable on the physical network.

    :param vlan_id: The VLAN ID.
    :param physical_network: The physical network.
    """
    message = _("Unable to create the network. "
                "The VLAN %(vlan_id)s on physical network "
                "%(physical_network)s is not available.")
